%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function doall=calc_THC_spectrum
% spectrum of GFDL THC index
close all; clear all; 
THC1=load('Data/ocean.0001-2000_THC_ATL_20N_0m_5000m.ascii');
THC2=load('Data/ocean.0001-2000_THC_ATL_20N_80N_0m_5000m.ascii');
run_num=1;
load(sprintf('Output/run%2.2d/THC_reconstructed.mat',run_num));

timeseries=zeros(1500,2);

% calculate spectrum of THC1:
timeseries(:,1)=THC1(501:2000);
timeseries(:,2)=[1:1500];
title_string=' '; % fprintf(1,title_string);
output_file_name_ext='THC1';
calculate_spectrum(timeseries,output_file_name_ext,title_string);

% calculate spectrum of THC2:
timeseries(:,1)=THC2(501:2000);
timeseries(:,2)=[1:1500];
title_string=' '; % fprintf(1,title_string);
output_file_name_ext='THC2';
calculate_spectrum(timeseries,output_file_name_ext,title_string);

% calculate spectrum of reconstructed THC1:
timeseries(:,1)=THC1_reconstructed;
timeseries(:,2)=[1:1500];
title_string=' '; % fprintf(1,title_string);
output_file_name_ext='THC1-reconstructed';
calculate_spectrum(timeseries,output_file_name_ext,title_string);

% calculate spectrum of reconstructed THC2:
timeseries(:,1)=THC2_reconstructed;
timeseries(:,2)=[1:1500];
title_string=' '; % fprintf(1,title_string);
output_file_name_ext='THC2-reconstructed';
calculate_spectrum(timeseries,output_file_name_ext,title_string);



status = fclose('all');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function calculate_spectrum(timeseries,output_file_name_ext,title_string);
% use Peter's routine to calculate and plot the spectrum.

% normalize timeseries:
x=timeseries(:,1);
avg=mean(x(:)); x(:)=x(:)-avg;
rms=std(x(:)); x(:)=x(:)/rms;

% set parameters and calculate spectrum:
dt=1;nw=3;qplot=0;if qplot;figure;end;nfft=length(x);
[P,s,ci] = pmtmPH(x,dt,nw,qplot,nfft);

% calculate upper and lower confidence intervals:
Ns=length(s);
cu(2:Ns)=P(2:Ns).*ci(2:Ns,1);
cl(2:Ns)=P(2:Ns).*ci(2:Ns,2);
period(1)=0;period(2:Ns)=1./s(2:Ns);

figure
gray=[.8 .8 .8];
axes('Position',[0.2 0.2 0.4 0.4])

% draw the confidence intervals as a gray background:
h=fill([period(2:Ns),period(Ns:-1:2),period(2)] ...
      ,[cu(2:Ns),    cl(Ns:-1:2),    cu(2)],gray);
set(h,'edgecolor',gray);
set(gca,'xscale','log'); set(gca,'yscale','log');
hold on
% draw the spectrum as a black line:
loglog(period(2:Ns),P(2:Ns),'k');

% reverse x axis to go from long periods to shorter ones:
set(gca,'XDir','reverse','YDir','default') 

% find minimum and maximum values of spectrum in plotted range:
period_min=2; period_max=1000;
max1=-1.e10;min1=1.e10;
for i=1:Ns
  if period(i)>period_min&&period(i)<period_max
    if cu(i)>max1; max1=cu(i); end
    if cl(i)<min1; min1=cl(i); end
  end
end

if 0
  % add arrows indicating Milankovitch frequencies:
  % close all; clear all; open Output/spectrum.fig;
  h(1)=line([100 100],[0.5 0.5]);       h(2)=line([100 100],[0.5/20 0.5]); 
  h(3)=line([41 41],  [0.05 0.05]);     h(4)=line([41 41],  [0.05/20 0.05]); 
  h(5)=line([23 23],  [0.006 0.006]);   h(6)=line([23 23],  [0.006/20 0.006]); 
  h(7)=line([19 19],  [0.004 0.004]); h(8)=line([19 19],  [0.004/20 0.004]); 
  for i=1:2:7; set(h(i), 'Marker','^','MarkerSize',6,'Color','k'); end;
  for i=2:2:8; set(h(i),'Color','k'); end;
end
  
% set period range to plot, print labels:
V=axis; axis([period_min period_max min1*0.5 max1*1.5])

h(1)=gca;
h(2)=xlabel('Period (yr)');
h(3)=ylabel('Power spectrum');
set(h,'FontName','Helvetica','FontWeight','bold','FontSize',12);

% draw accumulated power:
%loglog(period(2:Ns-1),accumulated_power(2:Ns-1),'r--');

% tick marks
%set(gca,'XTick',[0.1 1 10 100 1000]);
%set(gca,'YTick',[0.001 0.01 0.1 1 10 100]);

saveas(gcf,['Output/spectrum_',output_file_name_ext,'.fig'],'fig');
print(gcf,'-depsc',['Output/spectrum_',output_file_name_ext,'.eps'])

